debrix/hw/xorg/common Makefile.am, 1.1, 1.2 xf86DoScanPci.c, 1.2, 1.3 xf86Helper.c, 1.2, 1.3 xf86Init.c, 1.3, 1.4 xf86MiscExt.c, 1.3, 1.4 xf86pciBus.c, 1.3, 1.4

Daniel Stone xserver-commit at pdx.freedesktop.org
Thu Jul 1 10:49:53 PDT 2004


Committed by: daniel

Update of /cvs/xserver/debrix/hw/xorg/common
In directory pdx:/tmp/cvs-serv31934/hw/xorg/common

Modified Files:
	Makefile.am xf86DoScanPci.c xf86Helper.c xf86Init.c 
	xf86MiscExt.c xf86pciBus.c 
Log Message:
2004-06-29  Daniel Stone  <daniel at freedesktop.org>

	* configure.ac:
	Made CFLAGS a little less embarassingly large; fix it so the script
	actually runs and works fine (no more sed errors); remove XF86keysym.h
	check, which probably never actually worked. Get rid of INCLUDES;
	merge it into CFLAGS.

	* */Makefile.am:
	Sanitise INCLUDES/CFLAGS usage to radically decrease length of gcc
	lines.

	* include/Makefile.am:
	Make debrix.h depend on config.h, so they stay in sync. Oops.

	* hw/xorg/int10/xf86int10module.c:
	Change int10VersRec declaration from static, so debrixInit can see it.

	* hw/xorg/common/xf86KbdLnx.c:
	* hw/xorg/os-support/linux/lnx_KbdMap.c:
	Axe unused DECkeysym.h header dep.

	* hw/xorg/include/X11/extensions/Makefile.am:
	Finally fix the ext_HEADERS debacle.

	* hw/xorg/loader/dlloader.c:
	* hw/xorg/loader/loader.c:
	dlopen() NULL at startup, and include it in dlsym() searches, so we
	can find symbols included in the main binary with the standard module
	search.

	* hw/xorg/loader/loader.c:
	* hw/xorg/loader/loadmod.c:
	* hw/xorg/loader/xf86sym.c:
	* hw/xorg/common/xf86Init.c:
	Change loader API to introduce a new 'builtin' class, which doesn't
	actually load a module, but goes through all the motions; get rid of
	baseModules list for the time being (we don't want bitmap, and pcidata
	is already loaded). Explicitly add all ModuleData objects being loaded
	to xf86sym.c, so they don't get 'optimised' out.
	
	* hw/xorg/common/debrixInit.c:
	* hw/xorg/common/xf86Init.c:
	Add new debrixInit() function, which adds a few modules as builtins.

	* hw/xorg/loader/xf86sym.c:
	* hw/xorg/os-support/linux/Makefile.am:
	Re-enable a few missing os-support functions (xf86UDelay, xf86IODelay,
	xf86BusToMem, xf86MemToBus, xf86LoadKernelModule).

	* configure.ac:
	* fb/Makefile.am:
	* miext/shadow/Makefile.am:
	Make fb and shadow modular once more.

	* fb/fb.h:
	* render/filter.c:
	* render/picture.c:
	* include/picturestr.h:
	Rolled back to X.Org versions until I can figure out why pictures
	don't actually display in most cases.

	The following two are thanks to Jabuk Piotr C?apa.
	* os/xdmauth.c:
	"Xdmcp.h" -> <X11/Xdmcp.h>

	* hw/xorg/os-support/shared/drm/kernel/drm.h:
	Guard linux/config.h inclusion with #ifdef __KERNEL__.


Index: Makefile.am
===================================================================
RCS file: /cvs/xserver/debrix/hw/xorg/common/Makefile.am,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- Makefile.am	10 Jun 2004 19:14:51 -0000	1.1
+++ Makefile.am	1 Jul 2004 17:49:48 -0000	1.2
@@ -44,7 +44,7 @@
 libcommon_a_SOURCES = xf86Configure.c xf86Bus.c xf86Config.c \
                       xf86Cursor.c xf86DGA.c xf86DPMS.c xf86DefModes.c \
                       xf86DoProbe.c xf86DoScanPci.c xf86Events.c \
-                      xf86Globals.c xf86Io.c \
+                      xf86Globals.c xf86Io.c debrixInit.c \
                       xf86MiscExt.c xf86Option.c xf86PM.c \
                       xf86VidMode.c xf86fbman.c xf86cmap.c \
                       xf86Versions.c ../scanpci/xf86ScanPci.c \
@@ -55,10 +55,9 @@
 libmode_a_SOURCES = xf86Mode.c
 libinit_a_SOURCES = xf86Init.c
 
-INCLUDES = $(XORG_INCS) -I$(srcdir)/../loader -I$(srcdir)/../ddc \
-           -I$(srcdir)/../rac -I$(srcdir)/../vbe -I$(srcdir)/../int10 \
-           -I$(srcdir)/../i2c -I$(srcdir)/../parser -I$(srcdir)/../vgahw \
-           -I$(srcdir)/../scanpci -I$(top_srcdir)/Xi
+INCLUDES = -I$(srcdir)/../ddc -I$(srcdir)/../i2c -I$(srcdir)/../loader \
+           -I$(srcdir)/../rac -I$(srcdir)/../parser -I$(srcdir)/../scanpci \
+           -I$(srcdir)/../vbe -I$(srcdir)/../int10 -I$(srcdir)/../vgahw
 
 sdk_HEADERS = compiler.h fourcc.h xf86.h xf86Module.h xf86Opt.h \
                xf86PciInfo.h xf86Priv.h xf86Privstr.h xf86Resources.h \

Index: xf86DoScanPci.c
===================================================================
RCS file: /cvs/xserver/debrix/hw/xorg/common/xf86DoScanPci.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- xf86DoScanPci.c	10 Jun 2004 19:40:04 -0000	1.2
+++ xf86DoScanPci.c	1 Jul 2004 17:49:48 -0000	1.3
@@ -101,7 +101,7 @@
   LoaderSetPath(xf86ModulePath);
 
   if (!LoadModule("scanpci", NULL, NULL, NULL, NULL, NULL,
-                  &errmaj, &errmin)) {
+                  &errmaj, &errmin, 0)) {
     LoaderErrorMsg(NULL, "scanpci", errmaj, errmin);
     exit(1);
   }

Index: xf86Init.c
===================================================================
RCS file: /cvs/xserver/debrix/hw/xorg/common/xf86Init.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- xf86Init.c	10 Jun 2004 19:40:04 -0000	1.3
+++ xf86Init.c	1 Jul 2004 17:49:48 -0000	1.4
@@ -95,6 +95,10 @@
 extern int xtest_command_key;
 #endif /* XTESTEXT1 */
 
+#ifdef DEBRIX
+extern void debrixInit();
+#endif
+
 
 /* forward declarations */
 
@@ -115,10 +119,6 @@
 
 #ifdef XFree86LOADER
 static char *baseModules[] = {
-#if 0 /* XXX DS */
-	"bitmap",
-#endif
-	"pcidata",
 	NULL
 };
 #endif
@@ -337,6 +337,11 @@
     /* Initialise the loader */
     LoaderInit();
 
+#ifdef DEBRIX
+    /* Tell the loader about our built-ins. */
+    debrixInit();
+#endif
+
     /* Tell the loader the default module search path */
     LoaderSetPath(xf86ModulePath);
 
@@ -382,15 +387,19 @@
 
     xf86OpenConsole();
 
+    ErrorF("full io access\n");
     /* Enable full I/O access */
     xf86EnableIO();
 
+    ErrorF("busprobe\n");
     /* Do a general bus probe.  This will be a PCI probe for x86 platforms */
     xf86BusProbe();
 
+    ErrorF("doprobe\n");
     if (xf86DoProbe)
 	DoProbe();
 
+    ErrorF("doconfigure\n");
     if (xf86DoConfigure)
 	DoConfigure();
 
@@ -1873,7 +1882,7 @@
 	else
 	    opt = NULL;
 
-        if (!LoadModule(name, NULL, NULL, NULL, opt, NULL, &errmaj, &errmin)) {
+        if (!LoadModule(name, NULL, NULL, NULL, opt, NULL, &errmaj, &errmin, 0)) {
 	    LoaderErrorMsg(NULL, name, errmaj, errmin);
 	    failed = TRUE;
 	}

Index: xf86MiscExt.c
===================================================================
RCS file: /cvs/xserver/debrix/hw/xorg/common/xf86MiscExt.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- xf86MiscExt.c	12 Jun 2004 17:14:35 -0000	1.3
+++ xf86MiscExt.c	1 Jul 2004 17:49:48 -0000	1.4
@@ -61,7 +61,6 @@
 #endif
 
 #include "xf86OSmouse.h"
-/* XXX DS #include "../input/mouse/mouse.h" */
 
 #ifdef DEBUG
 # define DEBUG_P(x) ErrorF(x"\n");

Index: xf86pciBus.c
===================================================================
RCS file: /cvs/xserver/debrix/hw/xorg/common/xf86pciBus.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- xf86pciBus.c	10 Jun 2004 19:40:04 -0000	1.3
+++ xf86pciBus.c	1 Jul 2004 17:49:48 -0000	1.4
@@ -1711,6 +1711,7 @@
      */
 #ifdef XFree86LOADER
     xf86SetupPciIds = (ScanPciSetupProcPtr)LoaderSymbol("ScanPciSetupPciIds");
+    ErrorF("xf86SetupPciIds: %d\n", xf86SetupPciIds);
     xf86ClosePciIds = (ScanPciCloseProcPtr)LoaderSymbol("ScanPciClosePciIds");
     xf86FindPciNamesByDevice =
 	(ScanPciFindByDeviceProcPtr)LoaderSymbol("ScanPciFindPciNamesByDevice");




More information about the xserver-commit mailing list
Index: xf86Helper.c
===================================================================
RCS file: /cvs/xserver/debrix/hw/xorg/common/xf86Helper.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- xf86Helper.c	10 Jun 2004 19:40:04 -0000	1.2
+++ xf86Helper.c	1 Jul 2004 17:49:48 -0000	1.3
@@ -137,8 +137,9 @@
 void
 xf86AddModuleInfo(ModuleInfoPtr info, pointer module)
 {
-    /* Don't add null entries */
-    if (!module)
+    /* Don't add null entries
+     * ... but a NULL info is OK. -d */
+    if (!info)
 	return;
 
     if (xf86ModuleInfoList == NULL)
@@ -2432,7 +2433,7 @@
     }
 
 #ifdef XFree86LOADER
-    mod = LoadModule(Name, NULL, NULL, NULL, opt, NULL, &errmaj, &errmin);
+    mod = LoadModule(Name, NULL, NULL, NULL, opt, NULL, &errmaj, &errmin, 0);
     if (!mod)
 	LoaderErrorMsg(NULL, Name, errmaj, errmin);
 #else
